==> libplasma-6.3.1.tar.xz: libplasma-6.3.1/src/desktoptheme/breeze-dark/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "KDE Visual Design Group",
                "Name[ar]": "مجموعة التصميم المرئي لكِيدِي",
                "Name[az]": "KDE Vizual Dizayn Qrupu",
                "Name[be]": "Суполка візуальнага дызайну KDE",
                "Name[bg]": "KDE Visual Design Group",
                "Name[ca@valencia]": "Grup de disseny visual de KDE",
                "Name[ca]": "Grup de disseny visual de KDE",
                "Name[cs]": "Skupina vizuálního návrhu KDE",
                "Name[da]": "KDE visuelle designgruppe",
                "Name[de]": "KDE Visual Design Group",
                "Name[el]": "Ομάδα οπτικού σχεδιασμού KDE",
                "Name[en_GB]": "KDE Visual Design Group",
                "Name[eo]": "KDE Vida Dezajna Grupo",
                "Name[es]": "El grupo de diseño visual de KDE",
                "Name[eu]": "KDE Diseinu bisualeko taldea",
                "Name[fi]": "KDE:n visuaalinen suunnitteluryhmä",
                "Name[fr]": "Groupe de conception graphique de KDE « VDG » (Visual Design Group)",
                "Name[gl]": "Grupo de deseño visual de KDE",
                "Name[he]": "קבוצת העיצוב החזותי של KDE",
                "Name[hi]": "केडीई विज़ुअल डिज़ाइन समूह",
                "Name[hu]": "KDE Visual Design Group",
                "Name[ia]": "KDE Visual Design Group (Gruppo de Designo Visual de KDE)",
                "Name[id]": "Grup Desain Visual KDE",
                "Name[is]": "Myndrænn hönnunarhópur KDE",
                "Name[it]": "KDE Visual Design Group",
                "Name[ka]": "KDE Visual Design Group",
                "Name[ko]": "KDE 시각 디자인 그룹",
                "Name[lt]": "KDE vaizdinio dizaino grupė",
                "Name[lv]": "KDE Vizuālā dizaina grupa",
                "Name[nl]": "KDE Visuele ontwerpgroep",
                "Name[nn]": "KDE Visual Design Group",
                "Name[pl]": "Grupa oprawy graficznej KDE",
                "Name[pt]": "Grupo de Desenho Visual do KDE",
                "Name[pt_BR]": "Grupo de design visual do KDE (KDE VDG)",
                "Name[ro]": "KDE Visual Design Group",
                "Name[ru]": "Группа KDE Visual Design",
                "Name[sa]": "KDE Visual Design Group",
                "Name[sk]": "KDE Visual Design Group",
                "Name[sl]": "Skupina vizualnega designa KDE",
                "Name[sv]": "KDE:s visuella designgrupp",
                "Name[ta]": "கே.டீ.யீ. வரைகலை வடிவமைப்புக் குழு",
                "Name[tr]": "KDE Görsel Tasarım Grubu",
                "Name[uk]": "Група з візуального дизайну KDE",
                "Name[vi]": "Đội Thiết kế Trực quan KDE",
                "Name[x-test]": "xxKDE Visual Design Groupxx",
                "Name[zh_CN]": "KDE 视觉设计团队",
                "Name[zh_TW]": "KDE VDG 視覺設計組"
            }
        ],
        "Category": "",
        "Description": "Breeze Dark by the KDE VDG",
        "Description[ar]": "نسيم داكن من من مجموعة تصميم كِيدِي",
        "Description[az]": "KDE VDG tərəfindən Breeze Qara",
        "Description[be]": "Breeze Dark ад KDE VDG",
        "Description[bg]": "Breeze Тъмен от KDE VDG",
        "Description[ca@valencia]": "Brisa fosca, creat pel VDG de KDE",
        "Description[ca]": "Brisa fosca, creat pel VDG del KDE",
        "Description[cs]": "Breeze Dark od KDE VDG",
        "Description[da]": "Breeze Mørk af KDE's visuelle designgruppe",
        "Description[de]": "Breeze Dunkel von der KDE VDG",
        "Description[el]": "Breeze σκοτεινό από το KDE VDG",
        "Description[en_GB]": "Breeze Dark by the KDE VDG",
        "Description[eo]": "Breeze Dark de la KDE VDG",
        "Description[es]": "Brisa oscuro, por KDE VDG",
        "Description[eu]": "Brisa iluna KDEren VDGk egina",
        "Description[fi]": "Tumma Breeze KDE VDG:ltä",
        "Description[fr]": "Breeze sombre par l'équipe « KDE VDG »",
        "Description[gl]": "Brisa escura do KDE VDG.",
        "Description[he]": "בריזה כהה מאת קבוצת העיצוב החזותי של KDE",
        "Description[hi]": "केडीई वीडीजी द्वारा ब्रीज़ डार्क",
        "Description[hu]": "Breeze Dark a KDE VDG-től",
        "Description[ia]": "Breeze Dark (Brisa Obscure) per le KDE VDG",
        "Description[id]": "Breeze Gelap oleh KDE VDG",
        "Description[is]": "Breeze Dark frá KDE VDG",
        "Description[it]": "Brezza scuro a cura del KDE VDG",
        "Description[ka]": "Breeze Dark \"KDE VDG\"-სგან",
        "Description[ko]": "KDE 시각 디자인 그룹에서 제작한 어두운 Breeze",
        "Description[lt]": "Breeze tamsus pagal KDE VDG",
        "Description[lv]": "KDE VDG veidotā „Breeze Dark“",
        "Description[nl]": "Breeze Dark door de KDE VDG",
        "Description[nn]": "Breeze mørk frå KDE VDG",
        "Description[pl]": "Ciemna Bryza autorstwa KDE VDG",
        "Description[pt]": "Brisa Escuro da VDG do KDE",
        "Description[pt_BR]": "Breeze pelo KDE VDG",
        "Description[ro]": "Briză, întunecat, de KDE VDG",
        "Description[ru]": "Тёмный вариант Breeze от KDE VDG",
        "Description[sa]": "KDE VDG द्वारा Breeze Dark",
        "Description[sk]": "Vánok Tmavý od KDE VDG",
        "Description[sl]": "Temna sapica od KDE VDG",
        "Description[sv]": "Breeze mörk av KDE:s visuella designgrupp",
        "Description[ta]": "கே.டீ.யீ. VDG வழங்கும் கரும் பிரீஸ்",
        "Description[tr]": "KDE VDG’den Esinti Koyu",
        "Description[uk]": "Темна Breeze, автори — KDE VDG",
        "Description[vi]": "Breeze Tối, do KDE VDG",
        "Description[x-test]": "xxBreeze Dark by the KDE VDGxx",
        "Description[zh_CN]": "Breeze 微风深色主题，由 KDE VDG (视觉设计团队) 设计制作",
        "Description[zh_TW]": "由 KDE VDG 設計的 Breeze Dark",
        "EnabledByDefault": true,
        "Id": "breeze-dark",
        "License": "LGPL",
        "Name": "Breeze Dark",
        "Name[ar]": "نسيم داكن",
        "Name[az]": "Breeze Qara",
        "Name[be]": "Breeze Dark",
        "Name[bg]": "Breeze Тъмен",
        "Name[ca@valencia]": "Brisa fosca",
        "Name[ca]": "Brisa fosca",
        "Name[cs]": "Breeze Tmavé",
        "Name[da]": "Breeze Mørk",
        "Name[de]": "Breeze Dunkel",
        "Name[el]": "Breeze σκοτεινό",
        "Name[en_GB]": "Breeze Dark",
        "Name[eo]": "Vento Malhela",
        "Name[es]": "Brisa oscuro",
        "Name[eu]": "Brisa iluna",
        "Name[fi]": "Tumma Breeze",
        "Name[fr]": "Breeze Sombre",
        "Name[gl]": "Brisa escura",
        "Name[he]": "בריזה כהה",
        "Name[hi]": "ब्रीज़ डार्क",
        "Name[hu]": "Breeze Dark",
        "Name[ia]": "Brisa obscure",
        "Name[id]": "Breeze Gelap",
        "Name[is]": "Breeze Dark",
        "Name[it]": "Brezza scuro",
        "Name[ka]": "Breeze Dark",
        "Name[ko]": "어두운 Breeze",
        "Name[lt]": "Breeze tamsus",
        "Name[lv]": "Breeze Dark",
        "Name[nl]": "Breeze Dark",
        "Name[nn]": "Breeze mørk",
        "Name[pl]": "Ciemna Bryza",
        "Name[pt]": "Brisa Escura",
        "Name[pt_BR]": "Breeze Dark",
        "Name[ro]": "Briză, întunecat",
        "Name[ru]": "Breeze, тёмный вариант",
        "Name[sa]": "Breeze Dark",
        "Name[sk]": "Vánok Tmavý",
        "Name[sl]": "Temna sapica",
        "Name[sv]": "Breeze mörk",
        "Name[ta]": "கரும் பிரீஸ்",
        "Name[tr]": "Esinti Koyu",
        "Name[uk]": "Темна Breeze",
        "Name[vi]": "Breeze Tối",
        "Name[x-test]": "xxBreeze Darkxx",
        "Name[zh_CN]": "Breeze 微风深色",
        "Name[zh_TW]": "Breeze Dark",
        "Version": "@KF6_MIN_VERSION@",
        "Website": "https://www.kde.org/"
    },
    "X-Plasma-API": "5.0"
}

==> libplasma_6.3.4.orig.tar.xz: libplasma-6.3.4/src/desktoptheme/breeze-dark/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "KDE Visual Design Group",
                "Name[ar]": "مجموعة التصميم المرئي لكِيدِي",
                "Name[az]": "KDE Vizual Dizayn Qrupu",
                "Name[be]": "Суполка візуальнага дызайну KDE",
                "Name[bg]": "KDE Visual Design Group",
                "Name[ca@valencia]": "Grup de disseny visual de KDE",
                "Name[ca]": "Grup de disseny visual de KDE",
                "Name[cs]": "Skupina vizuálního návrhu KDE",
                "Name[da]": "KDE visuelle designgruppe",
                "Name[de]": "KDE Visual Design Group",
                "Name[el]": "Ομάδα οπτικού σχεδιασμού KDE",
                "Name[en_GB]": "KDE Visual Design Group",
                "Name[eo]": "KDE Vida Dezajna Grupo",
                "Name[es]": "El grupo de diseño visual de KDE",
                "Name[eu]": "KDE Diseinu bisualeko taldea",
                "Name[fi]": "KDE:n visuaalinen suunnitteluryhmä",
                "Name[fr]": "Groupe de conception graphique de KDE « VDG » (Visual Design Group)",
                "Name[gl]": "Grupo de deseño visual de KDE",
                "Name[he]": "קבוצת העיצוב החזותי של KDE",
                "Name[hi]": "केडीई विज़ुअल डिज़ाइन समूह",
                "Name[hu]": "KDE Visual Design Group",
                "Name[ia]": "KDE Visual Design Group (Gruppo de Designo Visual de KDE)",
                "Name[id]": "Grup Desain Visual KDE",
                "Name[is]": "Myndrænn hönnunarhópur KDE",
                "Name[it]": "KDE Visual Design Group",
                "Name[ka]": "KDE Visual Design Group",
                "Name[ko]": "KDE 시각 디자인 그룹",
                "Name[lt]": "KDE vaizdinio dizaino grupė",
                "Name[lv]": "KDE Vizuālā dizaina grupa",
                "Name[nb]": "KDE Visual Design Group",
                "Name[nl]": "KDE Visuele ontwerpgroep",
                "Name[nn]": "KDE Visual Design Group",
                "Name[pl]": "Grupa oprawy graficznej KDE",
                "Name[pt]": "Grupo de Desenho Visual do KDE",
                "Name[pt_BR]": "Grupo de design visual do KDE (KDE VDG)",
                "Name[ro]": "KDE Visual Design Group",
                "Name[ru]": "Группа KDE Visual Design",
                "Name[sa]": "KDE Visual Design Group",
                "Name[sk]": "KDE Visual Design Group",
                "Name[sl]": "Skupina vizualnega designa KDE",
                "Name[sv]": "KDE:s visuella designgrupp",
                "Name[ta]": "கே.டீ.யீ. வரைகலை வடிவமைப்புக் குழு",
                "Name[tr]": "KDE Görsel Tasarım Grubu",
                "Name[uk]": "Група з візуального дизайну KDE",
                "Name[vi]": "Đội Thiết kế Trực quan KDE",
                "Name[x-test]": "xxKDE Visual Design Groupxx",
                "Name[zh_CN]": "KDE 视觉设计团队",
                "Name[zh_TW]": "KDE VDG 視覺設計組"
            }
        ],
        "Category": "",
        "Description": "Breeze Dark by the KDE VDG",
        "Description[ar]": "نسيم داكن من من مجموعة تصميم كِيدِي",
        "Description[az]": "KDE VDG tərəfindən Breeze Qara",
        "Description[be]": "Breeze Dark ад KDE VDG",
        "Description[bg]": "Breeze Тъмен от KDE VDG",
        "Description[ca@valencia]": "Brisa fosca, creat pel VDG de KDE",
        "Description[ca]": "Brisa fosca, creat pel VDG del KDE",
        "Description[cs]": "Breeze Dark od KDE VDG",
        "Description[da]": "Breeze Mørk af KDE's visuelle designgruppe",
        "Description[de]": "Breeze Dunkel von der KDE VDG",
        "Description[el]": "Breeze σκοτεινό από το KDE VDG",
        "Description[en_GB]": "Breeze Dark by the KDE VDG",
        "Description[eo]": "Breeze Dark de la KDE VDG",
        "Description[es]": "Brisa oscuro, por KDE VDG",
        "Description[eu]": "Brisa iluna KDEren VDGk egina",
        "Description[fi]": "Tumma Breeze KDE VDG:ltä",
        "Description[fr]": "Breeze sombre par l'équipe « KDE VDG »",
        "Description[gl]": "Brisa escura do KDE VDG.",
        "Description[he]": "בריזה כהה מאת קבוצת העיצוב החזותי של KDE",
        "Description[hi]": "केडीई वीडीजी द्वारा ब्रीज़ डार्क",
        "Description[hu]": "Breeze Dark a KDE VDG-től",
        "Description[ia]": "Breeze Dark (Brisa Obscure) per le KDE VDG",
        "Description[id]": "Breeze Gelap oleh KDE VDG",
        "Description[is]": "Breeze Dark frá KDE VDG",
        "Description[it]": "Brezza scuro a cura del KDE VDG",
        "Description[ka]": "Breeze Dark \"KDE VDG\"-სგან",
        "Description[ko]": "KDE 시각 디자인 그룹에서 제작한 어두운 Breeze",
        "Description[lt]": "Breeze tamsus pagal KDE VDG",
        "Description[lv]": "KDE VDG veidotā „Breeze Dark“",
        "Description[nb]": "Breeze mørk fra KDE VDG",
        "Description[nl]": "Breeze Dark door de KDE VDG",
        "Description[nn]": "Breeze mørk frå KDE VDG",
        "Description[pl]": "Ciemna Bryza autorstwa KDE VDG",
        "Description[pt]": "Brisa Escuro da VDG do KDE",
        "Description[pt_BR]": "Breeze pelo KDE VDG",
        "Description[ro]": "Briză, întunecat, de KDE VDG",
        "Description[ru]": "Тёмный вариант Breeze от KDE VDG",
        "Description[sa]": "KDE VDG द्वारा Breeze Dark",
        "Description[sk]": "Vánok Tmavý od KDE VDG",
        "Description[sl]": "Temna sapica od KDE VDG",
        "Description[sv]": "Breeze mörk av KDE:s visuella designgrupp",
        "Description[ta]": "கே.டீ.யீ. VDG வழங்கும் கரும் பிரீஸ்",
        "Description[tr]": "KDE VDG’den Esinti Koyu",
        "Description[uk]": "Темна Breeze, автори — KDE VDG",
        "Description[vi]": "Breeze Tối, do KDE VDG",
        "Description[x-test]": "xxBreeze Dark by the KDE VDGxx",
        "Description[zh_CN]": "Breeze 微风深色主题，由 KDE VDG (视觉设计团队) 设计制作",
        "Description[zh_TW]": "由 KDE VDG 設計的 Breeze Dark",
        "EnabledByDefault": true,
        "Id": "breeze-dark",
        "License": "LGPL",
        "Name": "Breeze Dark",
        "Name[ar]": "نسيم داكن",
        "Name[az]": "Breeze Qara",
        "Name[be]": "Breeze Dark",
        "Name[bg]": "Breeze Тъмен",
        "Name[ca@valencia]": "Brisa fosca",
        "Name[ca]": "Brisa fosca",
        "Name[cs]": "Breeze Tmavé",
        "Name[da]": "Breeze Mørk",
        "Name[de]": "Breeze Dunkel",
        "Name[el]": "Breeze σκοτεινό",
        "Name[en_GB]": "Breeze Dark",
        "Name[eo]": "Vento Malhela",
        "Name[es]": "Brisa oscuro",
        "Name[eu]": "Brisa iluna",
        "Name[fi]": "Tumma Breeze",
        "Name[fr]": "Breeze Sombre",
        "Name[gl]": "Brisa escura",
        "Name[he]": "בריזה כהה",
        "Name[hi]": "ब्रीज़ डार्क",
        "Name[hu]": "Breeze Dark",
        "Name[ia]": "Brisa obscure",
        "Name[id]": "Breeze Gelap",
        "Name[is]": "Breeze Dark",
        "Name[it]": "Brezza scuro",
        "Name[ka]": "Breeze Dark",
        "Name[ko]": "어두운 Breeze",
        "Name[lt]": "Breeze tamsus",
        "Name[lv]": "Breeze Dark",
        "Name[nb]": "Breeze mørk",
        "Name[nl]": "Breeze Dark",
        "Name[nn]": "Breeze mørk",
        "Name[pl]": "Ciemna Bryza",
        "Name[pt]": "Brisa Escura",
        "Name[pt_BR]": "Breeze Dark",
        "Name[ro]": "Briză, întunecat",
        "Name[ru]": "Breeze, тёмный вариант",
        "Name[sa]": "Breeze Dark",
        "Name[sk]": "Vánok Tmavý",
        "Name[sl]": "Temna sapica",
        "Name[sv]": "Breeze mörk",
        "Name[ta]": "கரும் பிரீஸ்",
        "Name[tr]": "Esinti Koyu",
        "Name[uk]": "Темна Breeze",
        "Name[vi]": "Breeze Tối",
        "Name[x-test]": "xxBreeze Darkxx",
        "Name[zh_CN]": "Breeze 微风深色",
        "Name[zh_TW]": "Breeze Dark",
        "Version": "@KF6_MIN_VERSION@",
        "Website": "https://www.kde.org/"
    },
    "X-Plasma-API": "5.0"
}
